#define NO_PYTHON_WARNINGS 0
#define NUITKA_MAIN_IS_PACKAGE_BOOL 0
#define NUITKA_MAIN_MODULE_NAME "__main__"
#define SYSFLAG_BYTES_WARNING 0
#define SYSFLAG_ISOLATED 0
#define SYSFLAG_NO_RANDOMIZATION 0
#define SYSFLAG_NO_SITE 0
#define SYSFLAG_OPTIMIZE 0
#define SYSFLAG_UNBUFFERED 0
#define SYSFLAG_UTF8 0
#define SYSFLAG_VERBOSE 0
#define _NUITKA_NO_ANNOTATIONS 0
#define _NUITKA_NO_ASSERTS 0
#define _NUITKA_NO_DOCSTRINGS 0
